.. app documentation master file, created by
   sphinx-quickstart on Wed Oct 21 13:18:22 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Kamasutra's documentation!
============================================

Django Kamasutra is a way to feature types of content.

Contents:

.. toctree::
   :maxdepth: 2
   :glob:
   
   installation
   getting_started
   api
   
   reference/index
    
    
Helping Out
===========

* **Project Home Page** `https://github.com/washingtontimes/django-kamasutra/ <https://github.com/washingtontimes/django-kamasutra>`_


 
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

